GraphState class abstract

Implementers

Constructors

GraphState({required HashMap<ID, List<ID>> edges, required HashMap<ID, (double, double)> coords, required HashMap<ID, GraphNode> nodes, required HashMap<ID, ID> parents, required ID startId, required ID targetId, required Status status})
GraphState.init(ID startId, ID targetId, HashMap<ID, (double, double)> coords, HashMap<ID, List<ID>> edges)

Properties

coords ↔ HashMap<ID, (double, double)>
getter/setter pair
edges ↔ HashMap<ID, List<ID>>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
nodes ↔ HashMap<ID, GraphNode>
getter/setter pair
parents ↔ HashMap<ID, ID>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start → GraphPoint
no setter
startId ↔ int
getter/setter pair
status ↔ Status
getter/setter pair
target → GraphPoint
no setter
targetId ↔ int
getter/setter pair

Methods

copy() → GraphState
getNode(ID id) → GraphNode
getPoint(ID id) → GraphPoint
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override