GridState class abstract

Implementers

Constructors

GridState({required GridPoint start, required GridPoint target, required List<List<GridNode>> grid, required HashMap<GridPoint, GridPoint> parents, required Status status, required List<(int, int)> dirs})
GridState.init(GridPoint start, GridPoint target, List<List<GridNode>> grid, bool allowDiagonals)

Properties

dirs ↔ List<(int, int)>
getter/setter pair
grid ↔ List<List<GridNode>>
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
height → int
no setter
parents ↔ HashMap<GridPoint, GridPoint>
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
start ↔ GridPoint
getter/setter pair
status ↔ Status
getter/setter pair
target ↔ GridPoint
getter/setter pair
width → int
no setter

Methods

copy() → GridState
isUntraversable(GridPoint p) → bool
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
override